ExtImageCopyCaptureFrameV1PresentationTimeEvent class

presentation time of the frame

This event indicates the time at which the frame is presented to the output in system monotonic time. This event is sent before the ready event.

The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples, each component being an unsigned 32-bit value. Whole seconds are in tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo, and the additional fractional part in tv_nsec as nanoseconds. Hence, for valid timestamps tv_nsec must be in 0, 999999999.

Constructors

ExtImageCopyCaptureFrameV1PresentationTimeEvent(int tvSecHi, int tvSecLo, int tvNsec)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tvNsec int
nanoseconds part of the timestamp
final
tvSecHi int
high 32 bits of the seconds part of the timestamp
final
tvSecLo int
low 32 bits of the seconds part of the timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited