ExtImageCopyCaptureSessionV1BufferSizeEvent class

image capture source dimensions

Provides the dimensions of the source image in buffer pixel coordinates.

The client must attach buffers that match this size.

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
buffer height
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
buffer width
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited