ScreencopyFrameV1BufferDoneEvent class
all buffer types reported
This event is sent once after all buffer events have been sent.
The client should proceed to create a buffer of one of the supported types, and send a "copy" request.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited