VirtualPointerV1 class

virtual pointer

This protocol allows clients to emulate a physical pointer device. The requests are mostly mirror opposites of those specified in wl_pointer.

Inheritance

Constructors

VirtualPointerV1(Context innerContext)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
no getterinherited
innerContext Context
final
objectId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

axis(int time, int axis, double value) Result<void, Object>
axis event
axisDiscrete(int time, int axis, double value, int discrete) Result<void, Object>
axis click event
axisSource(int axisSource) Result<void, Object>
axis source event
axisStop(int time, int axis) Result<void, Object>
axis stop event
button(int time, int button, int state) Result<void, Object>
button event
destroy() Result<void, Object>
destroy the virtual pointer object
frame() Result<void, Object>
end of a pointer event sequence
motion(int time, double dx, double dy) Result<void, Object>
pointer relative motion event
motionAbsolute(int time, int x, int y, int xExtent, int yExtent) Result<void, Object>
pointer absolute motion event
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited