WlDataDevice class

data transfer device

There is one wl_data_device per seat which can be obtained from the global wl_data_device_manager singleton.

A wl_data_device provides access to inter-client data transfer mechanisms such as copy-and-paste and drag-and-drop.

Inheritance
Implemented types

Constructors

WlDataDevice(Context innerContext)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
no getterinherited
innerContext Context
final
objectId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

dispatch(int opcode, int fd, Uint8List data) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataOffer(WlDataDeviceDataOfferEventHandler handler) → void
introduce a new wl_data_offer
onDrop(WlDataDeviceDropEventHandler handler) → void
end drag-and-drop session successfully
onEnter(WlDataDeviceEnterEventHandler handler) → void
initiate drag-and-drop session
onLeave(WlDataDeviceLeaveEventHandler handler) → void
end drag-and-drop session
onMotion(WlDataDeviceMotionEventHandler handler) → void
drag-and-drop session motion
onSelection(WlDataDeviceSelectionEventHandler handler) → void
advertise new selection
release() Result<void, Object>
destroy data device
setSelection(WlDataSource source, int serial) Result<void, Object>
copy data to the selection
startDrag(WlDataSource source, WlSurface origin, WlSurface icon, int serial) Result<void, Object>
start drag-and-drop operation
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited