WlDataDeviceManager class

data transfer interface

The wl_data_device_manager is a singleton global object that provides access to inter-client data transfer mechanisms such as copy-and-paste and drag-and-drop. These mechanisms are tied to a wl_seat and this interface lets a client get a wl_data_device corresponding to a wl_seat.

Depending on the version bound, the objects created from the bound wl_data_device_manager object will have different requirements for functioning properly. See wl_data_source.set_actions, wl_data_offer.accept and wl_data_offer.finish for details.

Inheritance

Constructors

WlDataDeviceManager(Context innerContext)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
no getterinherited
innerContext Context
final
objectId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

createDataSource() Result<WlDataSource, Object>
create a new data source
getDataDevice(WlSeat seat) Result<WlDataDevice, Object>
create a new data device
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited