WlPointerAxisRelativeDirection enum

axis relative direction

This specifies the direction of the physical motion that caused a wl_pointer.axis event, relative to the wl_pointer.axis direction.

Inheritance
Available extensions

Values

identical → const WlPointerAxisRelativeDirection

physical motion matches axis direction

const WlPointerAxisRelativeDirection("identical", 0)
inverted → const WlPointerAxisRelativeDirection

physical motion is the inverse of the axis direction

const WlPointerAxisRelativeDirection("inverted", 1)

Properties

enumName String
final
enumValue int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WlPointerAxisRelativeDirection>
A constant List of the values in this enum, in order of their declaration.