WpColorManagerV1 class

color manager singleton

A singleton global interface used for getting color management extensions for wl_surface and wl_output objects, and for creating client defined image description objects. The extension interfaces allow getting the image description of outputs and setting the image description of surfaces.

Compositors should never remove this global.

Inheritance
Implemented types

Constructors

WpColorManagerV1(Context innerContext)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
no getterinherited
innerContext Context
final
objectId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
final

Methods

createIccCreator() Result<WpImageDescriptionCreatorIccV1, Object>
make a new ICC-based image description creator object
createParametricCreator() Result<WpImageDescriptionCreatorParamsV1, Object>
make a new parametric image description creator object
createWindowsScrgb() Result<WpImageDescriptionV1, Object>
create Windows-scRGB image description object
destroy() Result<void, Object>
destroy the color manager
dispatch(int opcode, int fd, Uint8List data) → void
override
getImageDescription(WpImageDescriptionReferenceV1 reference) Result<WpImageDescriptionV1, Object>
create an image description from a reference
getOutput(WlOutput output) Result<WpColorManagementOutputV1, Object>
create a color management interface for a wl_output
getSurface(WlSurface surface) Result<WpColorManagementSurfaceV1, Object>
create a color management interface for a wl_surface
getSurfaceFeedback(WlSurface surface) Result<WpColorManagementSurfaceFeedbackV1, Object>
create a color management feedback interface
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDone(WpColorManagerV1DoneEventHandler handler) → void
all features have been sent
onSupportedFeature(WpColorManagerV1SupportedFeatureEventHandler handler) → void
supported features
onSupportedIntent(WpColorManagerV1SupportedIntentEventHandler handler) → void
supported rendering intent
onSupportedPrimariesNamed(WpColorManagerV1SupportedPrimariesNamedEventHandler handler) → void
supported named primaries
onSupportedTfNamed(WpColorManagerV1SupportedTfNamedEventHandler handler) → void
supported named transfer characteristic
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited