ZwpKeyboardShortcutsInhibitManagerV1Error enum

Inheritance
  • Object
  • Enum
  • ZwpKeyboardShortcutsInhibitManagerV1Error
Available extensions

Values

alreadyInhibited → const ZwpKeyboardShortcutsInhibitManagerV1Error

the shortcuts are already inhibited for this surface

const ZwpKeyboardShortcutsInhibitManagerV1Error("already_inhibited", 0)

Properties

enumName String
final
enumValue int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ZwpKeyboardShortcutsInhibitManagerV1Error>
A constant List of the values in this enum, in order of their declaration.