ZwpTabletToolV1HardwareSerialEvent class

unique hardware serial number of the tool

If the physical tool can be identified by a unique 64-bit serial number, this event notifies the client of this serial number.

If multiple tablets are available in the same seat and the tool is uniquely identifiable by the serial number, that tool may move between tablets.

Otherwise, if the tool has no serial number and this event is missing, the tool is tied to the tablet it first comes into proximity with. Even if the physical tool is used on multiple tablets, separate wp_tablet_tool objects will be created, one per tablet.

This event is sent in the initial burst of events before the wp_tablet_tool.done event.

Constructors

ZwpTabletToolV1HardwareSerialEvent(int hardwareSerialHi, int hardwareSerialLo)

Properties

hardwareSerialHi int
the unique serial number of the tool, most significant bits
final
hardwareSerialLo int
the unique serial number of the tool, least significant bits
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited