ZwpTextInputV1EnterEvent class

enter event

Notify the text_input object when it received focus. Typically in response to an activate request.

Constructors

ZwpTextInputV1EnterEvent(int surface)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surface int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited