ExtImageCopyCaptureFrameV1ReadyEvent class
frame is available for reading
Called as soon as the frame is copied, indicating it is available for reading.
The buffer may be re-used by the client after this event.
After receiving this event, the client must destroy the object.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited