ExtImageCopyCaptureSessionV1BufferSizeEvent class
image capture source dimensions
Provides the dimensions of the source image in buffer pixel coordinates.
The client must attach buffers that match this size.
Constructors
- ExtImageCopyCaptureSessionV1BufferSizeEvent(int width, int height)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited