ExtSessionLockV1LockedEvent class
session successfully locked
This client is now responsible for displaying graphics while the session is locked and deciding when to unlock the session.
The locked event must not be sent until a new "locked" frame has been presented on all outputs and no security sensitive normal/unlocked content is possibly visible.
If this event is sent, making the destroy request is a protocol error, the lock object must be destroyed using the unlock_and_destroy request.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited