ExtWorkspaceGroupHandleV1WorkspaceEnterEvent class
workspace added to workspace group
This event is emitted whenever a workspace is assigned to this group. A workspace may only ever be assigned to a single group at a single point in time, but can be re-assigned during it's lifetime.
Constructors
- ExtWorkspaceGroupHandleV1WorkspaceEnterEvent(int workspace)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited