OutputConfigurationV1SucceededEvent class
configuration changes succeeded
Sent after the compositor has successfully applied the changes or tested them.
Upon receiving this event, the client should destroy this object.
If the current configuration has changed, events to describe the changes will be sent followed by a wlr_output_manager.done event.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited