VirtualPointerV1 class
virtual pointer
This protocol allows clients to emulate a physical pointer device. The requests are mostly mirror opposites of those specified in wl_pointer.
Constructors
- VirtualPointerV1(Context innerContext)
Properties
Methods
-
axis(
int time, int axis, double value) → Result< void, Object> - axis event
-
axisDiscrete(
int time, int axis, double value, int discrete) → Result< void, Object> - axis click event
-
axisSource(
int axisSource) → Result< void, Object> - axis source event
-
axisStop(
int time, int axis) → Result< void, Object> - axis stop event
- button event
-
destroy(
) → Result< void, Object> - destroy the virtual pointer object
-
frame(
) → Result< void, Object> - end of a pointer event sequence
-
motion(
int time, double dx, double dy) → Result< void, Object> - pointer relative motion event
-
motionAbsolute(
int time, int x, int y, int xExtent, int yExtent) → Result< void, Object> - pointer absolute motion event
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited