ZwpTabletPadStripV2PositionEvent class
position changed
Sent whenever the position on a strip changes.
The position is normalized to a range of 0, 65535, the 0-value
represents the top-most and/or left-most position of the strip in
the pad's current rotation.
Constructors
- ZwpTabletPadStripV2PositionEvent(int position)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited