ZwpTabletToolV2TypeEvent class
tool type
The tool type is the high-level type of the tool and usually decides the interaction expected from this tool.
This event is sent in the initial burst of events before the wp_tablet_tool.done event.
Constructors
- ZwpTabletToolV2TypeEvent(int toolType)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited