ZwpTextInputV3DeleteSurroundingTextEvent class
delete surrounding text
Notify when the text around the current cursor position should be deleted.
Before_length and after_length are the number of bytes before and after the current cursor index (excluding the selection) to delete.
If a preedit text is present, in effect before_length is counted from the beginning of it, and after_length from its end (see done event sequence).
Values set with this event are double-buffered. They must be applied and reset to initial on the next zwp_text_input_v3.done event.
The initial values of both before_length and after_length are 0.
Constructors
- ZwpTextInputV3DeleteSurroundingTextEvent(int beforeLength, int afterLength)
Properties
- afterLength → int
-
length of text after current cursor position
final
- beforeLength → int
-
length of text before current cursor position
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited