ZwpTextInputV3EnterEvent class
enter event
Notification that this seat's text-input focus is on a certain surface.
If client has created multiple text input objects, compositor must send this event to all of them.
When the seat has the keyboard capability the text-input focus follows the keyboard focus. This event sets the current surface for the text-input object.
Constructors
- ZwpTextInputV3EnterEvent(int surface)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited